Module async_api

Module async_api 

Optional async helpers for high-level EPUB opening.

This module is available with the async feature.

Functions

open_epub_file_async
Read an EPUB file asynchronously and open it as an EpubBook.
open_epub_file_async_with_options
Read an EPUB file asynchronously and open it as an EpubBook with options.