pub enum RenderPrepTrace {
Event,
Run {
style: Box<ComputedTextStyle>,
font: Box<FontResolutionTrace>,
},
}Expand description
Structured trace context for a streamed chapter item.
Variants
Event
Non-text structural event.
Run
Text run with style context and font-resolution trace.
Fields

style: Box<ComputedTextStyle>Style used for this run during resolution.

font: Box<FontResolutionTrace>Font resolution details for this run.
Implementations
Sourceimpl RenderPrepTrace
impl RenderPrepTrace
Sourcepub fn font_trace(&self) -> Option<&FontResolutionTrace>
pub fn font_trace(&self) -> Option<&FontResolutionTrace>
Return font-resolution trace when this item is a text run.
Sourcepub fn style_context(&self) -> Option<&ComputedTextStyle>
pub fn style_context(&self) -> Option<&ComputedTextStyle>
Return style context when this item is a text run.