MemoryBudget

Struct MemoryBudget 

pub struct MemoryBudget {
    pub max_entry_bytes: usize,
    pub max_css_bytes: usize,
    pub max_nav_bytes: usize,
    pub max_inline_style_bytes: usize,
    pub max_pages_in_memory: usize,
}
Hard memory/resource budgets for open/parse/style/layout/render paths.

Fields

max_entry_bytes: usize

Max bytes allowed for a single heavy entry read (e.g. chapter XHTML).

max_css_bytes: usize

Max bytes allowed for a stylesheet payload.

max_nav_bytes: usize

Max bytes allowed for a navigation document payload.

max_inline_style_bytes: usize

Max bytes allowed for a single inline style="..." attribute payload.

max_pages_in_memory: usize

Max page objects allowed in memory for eager consumers.