pub struct ChunkLimits {
pub max_read_chunk: usize,
pub max_text_accumulation: usize,
pub max_events_per_yield: usize,
pub max_stack_depth: usize,
}Expand description
Chunking limits for incremental processing.
Prevents single large allocations by breaking work into smaller chunks.
Fields
max_read_chunk: usizeMaximum bytes to process in a single read operation.
max_text_accumulation: usizeMaximum bytes for accumulated text before forcing a flush.
max_events_per_yield: usizeMaximum number of events to process before yielding control.
max_stack_depth: usizeMaximum depth for element stack.
Implementations
Sourceimpl ChunkLimits
impl ChunkLimits