ZipLimits

Struct ZipLimits 

pub struct ZipLimits {
    pub max_file_read_size: usize,
    pub max_mimetype_size: usize,
    pub strict: bool,
    pub max_eocd_scan: usize,
}
Runtime-configurable ZIP safety limits.

Fields

max_file_read_size: usize

Maximum compressed or uncompressed file size allowed for reads.

max_mimetype_size: usize

Maximum allowed size for the required mimetype entry.

strict: bool

Whether ZIP parsing should fail on strict structural issues.

max_eocd_scan: usize

Maximum bytes scanned from file tail while searching for EOCD.

Implementations

Source

impl ZipLimits

pub fn new(max_file_read_size: usize, max_mimetype_size: usize) -> Self

Create explicit ZIP limits.

pub fn with_strict(self, strict: bool) -> Self

Enable or disable strict ZIP parsing behavior.

pub fn with_max_eocd_scan(self, max_eocd_scan: usize) -> Self

Set a cap for EOCD tail scan bytes.